@@ -7,6 +7,7 @@
 # include "scorematchingad_forward.h"
 # include "likelihoods/likelihoods.hpp"
 # include "utils/PrintFor.hpp"
+# include "utils/pADFun.h"
 
 // declare a function that tapes a log likelihood
 CppAD::ADFun<double> tapellcpp(veca1 z, //data measurement tranformed to M manifold
@@ -19,13 +20,13 @@ CppAD::ADFun<double> tapellcpp(veca1 z, //data measurement tranformed to M manif
 
 
 //' @noRd
-//' @title Tape of a log-likelihood calculation 2
+//' @title Tape of a log-density calculation 2
 //' @param p dimension of measurements
 //' @param bd dimension of the parameter vector
 //' @param llname name of the likelihood function
 //' @return An RCpp::XPtr object pointing to the ADFun
 // [[Rcpp::export]]
-Rcpp::XPtr< CppAD::ADFun<double> > ptapell2(veca1 z_ad, //data measurement on the M manifold
+pADFun ptapell2(veca1 z_ad, //data measurement on the M manifold
                                      veca1 theta_ad,
                                      Rcpp::XPtr<llPtr> llfXPtr, //the log likelihood function
                                      transform_a1type & tran,
@@ -34,23 +35,23 @@ Rcpp::XPtr< CppAD::ADFun<double> > ptapell2(veca1 z_ad, //data measurement on th
                                      );
 
 //' @noRd
-//' @title Get an XPtr to a named log-likelihood function in source code of package
+//' @title Get an XPtr to a named log-density function in source code of package
 //' @param llname name of the likelihood function
-//' @return An RCpp::XPtr object pointing to a `llPtr` object of the log-likelihood function. Since `llPtr` is itself a pointer object, we have an XPtr pointing to a pointer that points to a function.
+//' @return An RCpp::XPtr object pointing to a `llPtr` object of the log-density function. Since `llPtr` is itself a pointer object, we have an XPtr pointing to a pointer that points to a function.
 // [[Rcpp::export]]
 Rcpp::XPtr<llPtr> getllptr(std::string llname);
 
-//' @name evalll
-//' @title Evaluate a custom log-likelihood function
-//' @description Evaluates a custom log-likelihood function from [`customll()`] without taping. This is useful to check that the custom log-likelihood is behaving.
-//' To check a tape of the custom log-likelihood use [`buildsmdtape()`] then [`evaltape()`].
-//' @param ll A compiled log-likelihood function created by [`customll()`].
-// ( ll is an XPtr to a llPtr object that points to a log-likelihood function )
-//' @param u A vector of measurements for an individual
-//' @param theta A vector of parameters
-//' @return The value of the log-likelihood at `u` with parameters `theta`.
+//' @rdname tape_uld
+//' @name tape_uld
+//' @param name Name of an inbuilt function. See details.
+//' @details
+//' For `tape_uld_inbuilt()`, currently available unnormalised log-density functions are:
+//'
+//' ```{r, results = "asis", echo = FALSE}
+//' cat(paste(" +", llnames), sep = "\n")
+//' ```
 //' @export
 // [[Rcpp::export]]
-a1type evalll(Rcpp::XPtr<llPtr> ll, const veca1& u, const veca1& theta);
+pADFun tape_uld_inbuilt(std::string name, veca1 x, veca1 theta);
 
 #endif
